@@ -2,11 +2,11 @@
 **  Copyright (c) 2006, 2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: config.c,v 1.3 2007/04/21 18:33:27 msk Exp $
+**  $Id: config.c,v 1.4 2007/08/03 15:28:10 msk Exp $
 */
 
 #ifndef lint
-static char config_c_id[] = "@(#)$Id: config.c,v 1.3 2007/04/21 18:33:27 msk Exp $";
+static char config_c_id[] = "@(#)$Id: config.c,v 1.4 2007/08/03 15:28:10 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -66,7 +66,7 @@ config_load(FILE *in, struct configdef *def, unsigned int *line)
 	int n = -1;
 	int err = 0;
 	unsigned int myline = 0;
-	unsigned int value = -1;
+	int value = -1;
 	char *p;
 	char *str = NULL;
 	struct config *new;
@@ -145,8 +145,7 @@ config_load(FILE *in, struct configdef *def, unsigned int *line)
 					break;
 
 				  case CONFIG_TYPE_INTEGER:
-					value = (unsigned int) strtoul(p, &q,
-					                               10);
+					value = (int) strtol(p, &q, 10);
 					if (*q != '\0')
 						err = 1;
 
@@ -194,12 +193,15 @@ config_load(FILE *in, struct configdef *def, unsigned int *line)
 		switch (new->cfg_type)
 		{
 		  case CONFIG_TYPE_STRING:
-			new->cfg_data = (void *) strdup(str);
+			new->cfg_string = strdup(str);
 			break;
 
 		  case CONFIG_TYPE_BOOLEAN:
+			new->cfg_bool = (bool) value;
+			break;
+
 		  case CONFIG_TYPE_INTEGER:
-			new->cfg_data = (void *) value;
+			new->cfg_int = value;
 			break;
 
 		  default:
@@ -260,10 +262,11 @@ config_check(struct config *head, struct configdef *def)
 **  Parameter:
 **  	head -- head of config list
 **  	name -- name of the parameter of interest
-**  	value -- data, or pointer to it (returned)
+**  	value -- where to write the result (returned)
+**  	size -- bytes available at "value"
 **
 **  Return value:
-**  	1 if the data was found, 0 otherwise.
+**  	1 if the data was found, 0 otherwise, -1 if the request was illegal
 **
 **  Notes:
 **  	"value" is a (void *).  It can be used directly, such as:
@@ -274,19 +277,40 @@ config_check(struct config *head, struct configdef *def)
 */
 
 int
-config_get(struct config *head, const char *name, void *value)
+config_get(struct config *head, const char *name, void *value, size_t size)
 {
 	struct config *cur;
 
 	assert(head != NULL);
 	assert(name != NULL);
 	assert(value != NULL);
+	assert(size > 0);
 
 	for (cur = head; cur != NULL; cur = cur->cfg_next)
 	{
 		if (strcasecmp(cur->cfg_name, name) == 0)
 		{
-			memcpy(value, &cur->cfg_data, sizeof value);
+			switch (cur->cfg_type)
+			{
+			  case CONFIG_TYPE_BOOLEAN:
+				if (size != sizeof(bool))
+					return -1;
+				memcpy(value, &cur->cfg_bool, size);
+				break;
+
+			  case CONFIG_TYPE_INTEGER:
+				if (size != sizeof(int))
+					return -1;
+				memcpy(value, &cur->cfg_int, size);
+				break;
+
+			  default:
+				if (size != sizeof(char *))
+					return -1;
+				memcpy(value, &cur->cfg_string, size);
+				break;
+			}
+
 			return 1;
 		}
 	}
