@@ -2,14 +2,14 @@
 **  Copyright (c) 2006-2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-config.h,v 1.28 2007/08/01 22:26:08 msk Exp $
+**  $Id: dkim-config.h,v 1.32 2007/10/05 18:35:30 msk Exp $
 */
 
 #ifndef _DKIM_CONFIG_H_
 #define _DKIM_CONFIG_H_
 
 #ifndef lint
-static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.28 2007/08/01 22:26:08 msk Exp $";
+static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.32 2007/10/05 18:35:30 msk Exp $";
 #endif /* !lint */
 
 struct configdef dkimf_config[] =
@@ -30,6 +30,7 @@ struct configdef dkimf_config[] =
 	{ "KeyFile",			CONFIG_TYPE_STRING,	FALSE },
 	{ "KeyList",			CONFIG_TYPE_STRING,	FALSE },
 	{ "InternalHosts",		CONFIG_TYPE_STRING,	FALSE },
+	{ "MaximumSignedBytes",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "MacroList",			CONFIG_TYPE_STRING,	FALSE },
 	{ "Minimum",			CONFIG_TYPE_STRING,	FALSE },
 	{ "Mode",			CONFIG_TYPE_STRING,	FALSE },
@@ -45,6 +46,7 @@ struct configdef dkimf_config[] =
 #ifdef POPAUTH
 	{ "POPDBFile",			CONFIG_TYPE_STRING,	FALSE },
 #endif /* POPAUTH */
+	{ "TestPublicKeys",		CONFIG_TYPE_STRING,	FALSE },
 	{ "Quarantine",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "RemoveARAll",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "RemoveARFrom",		CONFIG_TYPE_STRING,	FALSE },
@@ -63,10 +65,12 @@ struct configdef dkimf_config[] =
 #ifdef _FFR_STATS
 	{ "Statistics",			CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_STATS */
+	{ "StrictTestMode",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "SubDomains",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "Syslog",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "SyslogSuccess",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "UserID",			CONFIG_TYPE_STRING,	FALSE },
+	{ "UseSSPDeny",			CONFIG_TYPE_BOOLEAN,	FALSE },
 #ifdef _FFR_VBR
 	{ "VBR-Certifiers",		CONFIG_TYPE_STRING,	FALSE },
 	{ "VBR-TrustedCertifiers",	CONFIG_TYPE_STRING,	FALSE },
