@@ -2,22 +2,25 @@
 **  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-filter.h,v 1.101 2007/09/07 16:05:53 msk Exp $
+**  $Id: dkim-filter.h,v 1.118 2007/10/06 15:24:39 msk Exp $
 */
 
 #ifndef _DKIM_FILTER_H_
 #define _DKIM_FILTER_H_
 
 #ifndef lint
-static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.101 2007/09/07 16:05:53 msk Exp $";
+static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.118 2007/10/06 15:24:39 msk Exp $";
 #endif /* !lint */
 
 #define	DKIMF_PRODUCT	"Sendmail DKIM Filter"
-#define	DKIMF_VERSION	"2.2.1"
+#define	DKIMF_VERSION	"2.3.0"
 
 /* libsm */
 #include <sm/gen.h>
 
+/* libmilter */
+#include <libmilter/mfapi.h>
+
 /* libdkim */
 #include <dkim.h>
 
@@ -31,8 +34,9 @@ static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.101 2007/09/07 16:0
 
 /* defaults, limits, etc. */
 #define	BUFRSZ		1024
+#define	CACHESTATSINT	300
 #define	CBINTERVAL	3
-#define CMDLINEOPTS	"a:Ab:c:C:d:Dfhi:I:k:KlL:m:M:o:p:P:qrRs:S:T:u:U:Vx:?"
+#define CMDLINEOPTS	"a:Ab:c:C:d:DfF:hi:I:k:KlL:m:M:o:p:P:qrRs:S:t:T:u:U:vVx:?"
 #define	DEFTIMEOUT	5
 #define	HOSTUNKNOWN	"unknown-host"
 #define	JOBIDUNKNOWN	"(unknown-jobid)"
@@ -76,4 +80,16 @@ struct Peer
 extern bool dolog;
 extern char *progname;
 
+/* prototypes, exported for test.c */
+extern sfsistat mlfi_connect __P((SMFICTX *, char *, _SOCK_ADDR *));
+extern sfsistat mlfi_envfrom __P((SMFICTX *, char **));
+extern sfsistat mlfi_header __P((SMFICTX *, char *, char *));
+extern sfsistat mlfi_eoh __P((SMFICTX *));
+extern sfsistat mlfi_body __P((SMFICTX *, u_char *, size_t));
+extern sfsistat mlfi_eom __P((SMFICTX *));
+extern sfsistat mlfi_abort __P((SMFICTX *));
+extern sfsistat mlfi_close __P((SMFICTX *));
+
+extern DKIM *dkimf_getdkim __P((void *));
+
 #endif /* _DKIM_FILTER_H_ */
