@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.22 2007/09/07 00:28:57 msk Exp $";
+static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.23 2007/09/17 16:41:29 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -927,10 +927,7 @@ dkim_canon_runheaders(DKIM *dkim, bool signing)
 			SHA1_Final(sha1->sha1_out, &sha1->sha1_ctx);
 
 			if (sha1->sha1_tmpbio != NULL)
-			{
-				BIO_free(sha1->sha1_tmpbio);
-				sha1->sha1_tmpbio = NULL;
-			}
+				BIO_flush(sha1->sha1_tmpbio);
 
 			break;
 		  }
@@ -944,10 +941,7 @@ dkim_canon_runheaders(DKIM *dkim, bool signing)
 			SHA256_Final(sha256->sha256_out, &sha256->sha256_ctx);
 
 			if (sha256->sha256_tmpbio != NULL)
-			{
-				BIO_free(sha256->sha256_tmpbio);
-				sha256->sha256_tmpbio = NULL;
-			}
+				BIO_flush(sha256->sha256_tmpbio);
 
 			break;
 		  }
@@ -1027,10 +1021,7 @@ dkim_canon_signature(DKIM *dkim, struct dkim_header *hdr)
 			SHA1_Final(sha1->sha1_out, &sha1->sha1_ctx);
 
 			if (sha1->sha1_tmpbio != NULL)
-			{
-				BIO_free(sha1->sha1_tmpbio);
-				sha1->sha1_tmpbio = NULL;
-			}
+				BIO_flush(sha1->sha1_tmpbio);
 
 			break;
 		  }
@@ -1044,10 +1035,7 @@ dkim_canon_signature(DKIM *dkim, struct dkim_header *hdr)
 			SHA256_Final(sha256->sha256_out, &sha256->sha256_ctx);
 
 			if (sha256->sha256_tmpbio != NULL)
-			{
-				BIO_free(sha256->sha256_tmpbio);
-				sha256->sha256_tmpbio = NULL;
-			}
+				BIO_flush(sha256->sha256_tmpbio);
 
 			break;
 		  }
@@ -1280,10 +1268,7 @@ dkim_canon_closebody(DKIM *dkim)
 			SHA1_Final(sha1->sha1_out, &sha1->sha1_ctx);
 
 			if (sha1->sha1_tmpbio != NULL)
-			{
-				BIO_free(sha1->sha1_tmpbio);
-				sha1->sha1_tmpbio = NULL;
-			}
+				BIO_flush(sha1->sha1_tmpbio);
 
 			break;
 		  }
@@ -1297,10 +1282,7 @@ dkim_canon_closebody(DKIM *dkim)
 			SHA256_Final(sha256->sha256_out, &sha256->sha256_ctx);
 
 			if (sha256->sha256_tmpbio != NULL)
-			{
-				BIO_free(sha256->sha256_tmpbio);
-				sha256->sha256_tmpbio = NULL;
-			}
+				BIO_flush(sha256->sha256_tmpbio);
 
 			break;
 		  }
@@ -1400,7 +1382,11 @@ dkim_canon_free(DKIM *dkim, DKIM_CANON *canon)
 			sha1 = (struct dkim_sha1 *) canon->canon_hash;
 
 			if (sha1->sha1_tmpbio != NULL)
+			{
 				BIO_free(sha1->sha1_tmpbio);
+				sha1->sha1_tmpfd = -1;
+				sha1->sha1_tmpbio = NULL;
+			}
 
 			break;
 		  }
@@ -1413,7 +1399,11 @@ dkim_canon_free(DKIM *dkim, DKIM_CANON *canon)
 			sha256 = (struct dkim_sha256 *) canon->canon_hash;
 
 			if (sha256->sha256_tmpbio != NULL)
+			{
 				BIO_free(sha256->sha256_tmpbio);
+				sha256->sha256_tmpfd = -1;
+				sha256->sha256_tmpbio = NULL;
+			}
 
 			break;
 		  }
