@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.25 2007/09/07 00:28:57 msk Exp $";
+static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.27 2007/09/24 20:08:31 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -18,6 +18,8 @@ static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.25 2007/09/07 00:28:57
 #include <assert.h>
 #include <stdio.h>
 #include <ctype.h>
+#include <string.h>
+#include <errno.h>
 
 /* libsm includes */
 #include <sm/string.h>
