@@ -7,7 +7,7 @@
 #define _DKIM_TYPES_H_
 
 #ifndef lint
-static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.61 2007/06/25 20:30:19 msk Exp $";
+static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.73 2007/08/20 17:02:13 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -39,6 +39,16 @@ static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.61 2007/06/25 20:30:1
 /* libdkim includes */
 #include "dkim.h"
 
+/* struct dkim_dstring -- a dynamically-sized string */
+struct dkim_dstring
+{
+	int			ds_alloc;
+	int			ds_max;
+	int			ds_len;
+	DKIM *			ds_dkim;
+	char *			ds_buf;
+};
+
 /* struct dkim_header -- an RFC2822 header of some kind */
 struct dkim_header
 {
@@ -47,6 +57,9 @@ struct dkim_header
 	struct dkim_header *	hdr_next;
 };
 
+/* hdr_flags bits */
+#define	DKIM_HDR_SIGNED		0x01
+
 /* struct dkim_plist -- a parameter/value pair */
 struct dkim_plist
 {
@@ -61,6 +74,7 @@ struct dkim_set
 	bool			set_done;
 	dkim_set_t		set_type;
 	u_char *		set_data;
+	void *			set_udata;
 	struct dkim_plist *	set_plist;
 	struct dkim_set *	set_next;
 };
@@ -69,10 +83,31 @@ struct dkim_set
 struct dkim_siginfo
 {
 	u_int			sig_flags;
-	u_int			sig_index;
+	u_int			sig_error;
 	u_int			sig_bh;
+	u_int			sig_version;
+	u_int			sig_hashtype;
+	u_int			sig_sigtype;
+	u_int			sig_keybits;
+	size_t			sig_siglen;
+	size_t			sig_keylen;
+	size_t			sig_b64keylen;
+	time_t			sig_timestamp;
+	dkim_query_t		sig_query;
+	dkim_alg_t		sig_signalg;
+	dkim_canon_t		sig_hdrcanonalg;
+	dkim_canon_t		sig_bodycanonalg;
+	u_char *		sig_domain;
+	u_char *		sig_selector;
+	u_char *		sig_sig;
+	u_char *		sig_key;
+	u_char *		sig_b64key;
 	void *			sig_context;
+	void *			sig_signature;
+	struct dkim_canon *	sig_hdrcanon;
+	struct dkim_canon *	sig_bodycanon;
 	struct dkim_set *	sig_taglist;
+	struct dkim_set *	sig_keytaglist;
 };
 
 /* struct dkim_sha1 -- stuff needed to do a sha1 hash */
@@ -95,6 +130,28 @@ struct dkim_sha256
 };
 #endif /* SHA256_DIGEST_LENGTH */
 
+/* struct dkim_canon -- a canonicalization status handle */
+struct dkim_canon
+{
+	bool			canon_done;
+	bool			canon_hdr;
+	bool			canon_blankline;
+	int			canon_lastchar;
+	u_int			canon_hashtype;
+	u_int			canon_blanks;
+	size_t			canon_hashbuflen;
+	size_t			canon_hashbufsize;
+	off_t			canon_remain;
+	off_t			canon_wrote;
+	off_t			canon_length;
+	dkim_canon_t		canon_canon;
+	u_char *		canon_hashbuf;
+	u_char *		canon_hdrlist;
+	void *			canon_hash;
+	struct dkim_header *	canon_sigheader;
+	struct dkim_canon *	canon_next;
+};
+
 /* struct dkim_rsa -- stuff needed to do RSA sign/verify */
 struct dkim_rsa
 {
@@ -111,31 +168,22 @@ struct dkim_rsa
 /* struct dkim -- a complete DKIM transaction context */
 struct dkim
 {
-	u_char			dkim_lastchar;
-	bool			dkim_writesep;
 	bool			dkim_partial;
 	bool			dkim_bodydone;
-	bool			dkim_blankline;
 	bool			dkim_subdomain;
 	bool			dkim_skipbody;
-	int			dkim_signum;
 	int			dkim_mode;
 	int			dkim_state;
 	int			dkim_timeout;
-	int			dkim_hashtype;
-	int			dkim_sigtype;
+	int			dkim_presult;
 #ifdef _FFR_QUERY_CACHE
 	u_int			dkim_cache_queries;
 	u_int			dkim_cache_hits;
 #endif /* _FFR_QUERY_CACHE */
-	u_int			dkim_blanks;
-	u_int			dkim_keybits;
 	u_int			dkim_version;
 	u_int			dkim_sigcount;
-	size_t			dkim_b64keylen;
 	size_t			dkim_b64siglen;
 	size_t			dkim_keylen;
-	size_t			dkim_siglen;
 	size_t			dkim_errlen;
 	time_t			dkim_timestamp;
 	dkim_query_t		dkim_querymethod;
@@ -144,35 +192,21 @@ struct dkim
 	dkim_alg_t		dkim_signalg;
 	off_t			dkim_bodylen;
 	off_t			dkim_signlen;
-	off_t			dkim_canonlen;
-#ifdef _FFR_HASH_BUFFERING
-	u_int			dkim_hashbuflen;
-	u_int			dkim_hashbufsize;
-	u_char *		dkim_hashbuf;
-#endif /* _FFR_HASH_BUFFERING */
 	const char *		dkim_id;
 	u_char *		dkim_domain;
 	u_char *		dkim_user;
 	u_char *		dkim_selector;
-	u_char *		dkim_hdrlist;
 	u_char *		dkim_b64key;
 	u_char *		dkim_b64sig;
 	u_char *		dkim_key;
-	u_char *		dkim_sig;
 	u_char *		dkim_reportaddr;
 	u_char *		dkim_sender;
 	u_char *		dkim_signer;
 	u_char *		dkim_error;
+	u_char *		dkim_hdrlist;
 	u_char *		dkim_zdecode;
-#ifdef _FFR_VBR
-	u_char *		dkim_vbr_type;
-	u_char *		dkim_vbr_cert;
-	u_char **		dkim_vbr_trusted;
-#endif /* _FFR_VBR */
 	char *			dkim_tmpdir;
-	void *			dkim_hash;
-	void *			dkim_bhash;
-	void *			dkim_signature;
+	DKIM_SIGINFO *		dkim_signature;
 	void *			dkim_closure;
 	const void *		dkim_user_context;
 	struct dkim_siginfo **	dkim_siglist;
@@ -182,6 +216,10 @@ struct dkim
 	struct dkim_header *	dkim_hhead;
 	struct dkim_header *	dkim_htail;
 	struct dkim_header *	dkim_senderhdr;
+	struct dkim_canon *	dkim_canonhead;
+	struct dkim_canon *	dkim_canontail;
+	struct dkim_dstring *	dkim_hdrbuf;
+	struct dkim_dstring *	dkim_canonbuf;
 	DKIM_LIB *		dkim_libhandle;
 };
 
@@ -196,11 +234,15 @@ struct dkim_lib
 	u_int			dkiml_callback_int;
 	time_t			dkiml_fixedtime;
 	time_t			dkiml_sigttl;
+	time_t			dkiml_clockdrift;
 	dkim_query_t		dkiml_querymethod;
 	void *			(*dkiml_malloc) (void *closure, size_t nbytes);
 	void			(*dkiml_free) (void *closure, void *p);
 #if USE_ARLIB
 	AR_LIB			dkiml_arlib;
+# ifdef _FFR_DNS_UPGRADE
+	AR_LIB			dkiml_arlibtcp;
+# endif /* _FFR_DNS_UPGRADE */
 #endif /* USE_ARLIB */
 	u_char **		dkiml_senderhdrs;
 	u_char **		dkiml_alwayshdrs;
@@ -209,11 +251,15 @@ struct dkim_lib
 #endif /* _FFR_QUERY_CACHE */
 	regex_t			dkiml_hdrre;
 	regex_t			dkiml_skiphdrre;
-	int			(*dkiml_key_lookup) (DKIM *dkim, u_char *buf,
+	DKIM_CBSTAT		(*dkiml_key_lookup) (DKIM *dkim,
+				                     DKIM_SIGINFO *sig,
+				                     u_char *buf,
 				                     size_t buflen);
-	int			(*dkiml_policy_lookup) (DKIM *dkim,
+	DKIM_CBSTAT		(*dkiml_policy_lookup) (DKIM *dkim,
+				                        u_char *query,
 				                        u_char *buf,
-				                        size_t buflen);
+				                        size_t buflen,
+				                        int *qstat);
 	void *			(*dkiml_sig_handle) (void *closure);
 	void			(*dkiml_sig_handle_free) (void *closure,
 				                          void *user);
@@ -221,8 +267,12 @@ struct dkim_lib
 				                        dkim_param_t pcode,
 				                        const u_char *param,
 				                        const u_char *value);
-	DKIM_STAT		(*dkiml_prescreen) (DKIM_SIGINFO **sigs,
+	DKIM_CBSTAT		(*dkiml_prescreen) (DKIM *dkim,
+				                    DKIM_SIGINFO **sigs,
 				                    int nsigs);
+	DKIM_CBSTAT		(*dkiml_final) (DKIM *dkim,
+				                DKIM_SIGINFO **sigs,
+				                int nsigs);
 	void			(*dkiml_dns_callback) (const void *context);
 	u_char			dkiml_tmpdir[MAXPATHLEN + 1];
 	u_char			dkiml_queryinfo[MAXPATHLEN + 1];
