@@ -7,7 +7,7 @@
 #define _DKIM_H_
 
 #ifndef lint
-static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.134 2007/09/07 00:28:57 msk Exp $";
+static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.140 2007/10/05 19:31:11 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -31,7 +31,7 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.134 2007/09/07 00:28:57 msk Exp $
 **  	pp == patch number
 */
 
-#define	DKIM_LIB_VERSION	0x02020100
+#define	DKIM_LIB_VERSION	0x02030000
 
 /* the basics */
 #ifndef NULL
@@ -76,6 +76,7 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.134 2007/09/07 00:28:57 msk Exp $
 /* version */
 #define	DKIM_VERSION_KEY	"DKIM1"	/* current version token for keys */
 #define	DKIM_VERSION_SIG	"1"	/* current version token for sigs */
+#define	DKIM_VERSION_SIGOLD	"0.5"	/* old version token for sigs */
 
 /* headers */
 #define	DKIM_FROMHEADER		"From"	/* From: header */
@@ -155,6 +156,7 @@ typedef int DKIM_SIGERROR;
 #define DKIM_SIGERROR_MISSING_BH	25	/* bh= missing */
 #define DKIM_SIGERROR_EMPTY_BH		26	/* bh= empty */
 #define DKIM_SIGERROR_CORRUPT_BH	27	/* bh= corrupt */
+#define DKIM_SIGERROR_BADSIG		28	/* signature mismatch */
 
 /*
 **  DKIM_CANON -- canonicalization method
@@ -240,9 +242,10 @@ typedef int dkim_key_t;
 
 typedef int dkim_pparam_t;
 
-# define DKIM_PPARAM_POLICY	0	/* dkim */
-# define DKIM_PPARAM_FLAGS	1	/* t */
-# define DKIM_PPARAM_REPORTADDR	2	/* r */
+#define DKIM_PPARAM_POLICY	0	/* dkim */
+#define DKIM_PPARAM_FLAGS	1	/* t */
+#define DKIM_PPARAM_REPORTADDR	2	/* r */
+#define DKIM_PPARAM_HANDLING	3	/* handling */
 
 /*
 **  DKIM_POLICY -- policies
@@ -258,6 +261,18 @@ typedef int dkim_policy_t;
 #define DKIM_POLICY_DEFAULT	DKIM_POLICY_UNKNOWN
 #define DKIM_POLICY_DEFAULTTXT	"dkim=unknown"
 
+/*
+**  DKIM_HANDLING -- suspicious message handling
+*/
+
+typedef int dkim_handling_t;
+
+#define	DKIM_HANDLING_NONE	(-1)	/* none/undefined */
+#define	DKIM_HANDLING_PROCESS	0	/* process message */
+#define	DKIM_HANDLING_DENY	1	/* block/reject message */
+
+#define	DKIM_HANDLING_DEFAULT	DKIM_HANDLING_PROCESS
+
 /*
 **  DKIM_PFLAG -- policy flags
 */
@@ -267,7 +282,6 @@ typedef int dkim_policy_t;
 
 #define DKIM_PFLAG_DEFAULT	0x00
 
-
 /*
 **  DKIM_PRESULT -- policy results
 */
@@ -282,6 +296,14 @@ typedef int dkim_policy_t;
 #define DKIM_PRESULT_VALIDOSIG		6	/* valid originator sig. */
 #define DKIM_PRESULT_POLICYERROR	7	/* policy check failed */
 
+/*
+**  DKIM_MODE -- mode of a handle
+*/
+
+#define	DKIM_MODE_UNKNOWN	(-1)
+#define	DKIM_MODE_SIGN		0
+#define	DKIM_MODE_VERIFY	1
+
 /*
 **  DKIM_SETTYPE -- types of sets
 */
@@ -348,6 +370,7 @@ typedef int dkim_opts_t;
 #define DKIM_LIBFLAGS_ZTAGS		0x10
 #define DKIM_LIBFLAGS_DELAYSIGPROC	0x20
 #define DKIM_LIBFLAGS_EOHCHECK		0x40
+#define DKIM_LIBFLAGS_ACCEPTV05		0x80
 
 #define	DKIM_LIBFLAGS_DEFAULT		DKIM_LIBFLAGS_NONE
 
@@ -581,6 +604,27 @@ extern DKIM_STAT dkim_body __P((DKIM *dkim, u_char *buf, size_t len));
 
 extern DKIM_STAT dkim_eom __P((DKIM *dkim, bool *testkey));
 
+#ifdef _FFR_QUERY_CACHE
+/*
+**  DKIM_GETCACHESTATS -- retrieve cache statistics
+**
+**  Parameters:
+**  	queries -- number of queries handled (returned)
+**  	hits -- number of cache hits (returned)
+**  	expired -- number of expired hits (returned)
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	Any of the parameters may be NULL if the corresponding datum
+**  	is not of interest.
+*/
+
+extern void dkim_getcachestats __P((u_int *queries, u_int *hits,
+                                    u_int *expired));
+#endif /* _FFR_QUERY_CACHE */
+
 /*
 **  DKIM_GETSIGLIST -- retrieve the list of signatures
 **
@@ -832,6 +876,18 @@ extern DKIM_STAT dkim_set_user_context __P((DKIM *dkim, const void *ctx));
 
 extern const void *dkim_get_user_context __P((DKIM *dkim));
 
+/*
+**  DKIM_GETMODE -- return the mode (signing, verifying, etc.) of a handle
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**
+**  Return value:
+**  	A DKIM_MODE_* constant.
+*/
+
+extern int dkim_getmode __P((DKIM *dkim));
+
 /*
 **  DKIM_SET_SIGNER -- set DKIM signature's signer
 **
@@ -1034,13 +1090,15 @@ extern void dkim_sig_ignore __P((DKIM_SIGINFO *siginfo));
 **  	test -- policy test flag (returned)
 **  	susp -- suspicious message flag (returned)
 **  	pcode -- discovered policy (returned)
+**  	hcode -- recommended suspicious message handling (returned)
 **
 **  Return value:
 **  	A DKIM_STAT_* constant.
 */
 
 extern DKIM_STAT dkim_policy __P((DKIM *dkim, bool *test, bool *susp,
-                                  dkim_policy_t *pcode));
+                                  dkim_policy_t *pcode,
+                                  dkim_handling_t *hcode));
 
 /*
 **  DKIM_SIG_PROCESS -- process a signature
