@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test42_c_id[] = "@(#)$Id: t-test42.c,v 1.16 2007/08/08 17:54:59 msk Exp $";
+static char t_test42_c_id[] = "@(#)$Id: t-test42.c,v 1.17 2007/09/20 22:21:01 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -122,6 +122,8 @@ main(int argc, char **argv)
 	int testpolicy;
 	int suspicious;
 	DKIM_STAT status;
+	dkim_policy_t pcode;
+	dkim_handling_t hcode;
 	DKIM *dkim;
 	DKIM_LIB *lib;
 	unsigned char hdr[MAXHEADER + 1];
@@ -228,8 +230,10 @@ main(int argc, char **argv)
 
 	testpolicy = 0;
 	suspicious = 0;
-	status = dkim_policy(dkim, &testpolicy, &suspicious, NULL);
+	status = dkim_policy(dkim, &testpolicy, &suspicious, &pcode, &hcode);
 	assert(status == DKIM_STAT_OK);
+	assert(pcode == DKIM_POLICY_UNKNOWN);
+	assert(hcode == DKIM_HANDLING_PROCESS);
 
 	status = dkim_free(dkim);
 	assert(status == DKIM_STAT_OK);
