@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test49_c_id[] = "@(#)$Id: t-test49.c,v 1.3 2007/06/15 00:22:36 msk Exp $";
+static char t_test49_c_id[] = "@(#)$Id: t-test49.c,v 1.8 2007/08/02 06:08:42 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -12,9 +12,12 @@ static char t_test49_c_id[] = "@(#)$Id: t-test49.c,v 1.3 2007/06/15 00:22:36 msk
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
+#include <unistd.h>
 
 /* libdb includes */
-#include <db.h>
+#ifdef _FFR_QUERY_CACHE
+# include <db.h>
+#endif /* _FFR_QUERY_CACHE */
 
 /* libdkim includes */
 #include "dkim.h"
@@ -42,9 +45,9 @@ main(int argc, char **argv)
 	printf("*** query caching SKIPPED\n");
 
 #else /* ! _FFR_QUERY_CACHE */
+
 	int status;
 	int err;
-	u_int flags;
 	size_t buflen;
 	DB *cache;
 	char buf[BUFRSZ + 1];
