@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test53_c_id[] = "@(#)$Id: t-test53.c,v 1.5 2007/06/15 00:22:36 msk Exp $";
+static char t_test53_c_id[] = "@(#)$Id: t-test53.c,v 1.9 2007/07/27 05:39:47 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -43,9 +43,11 @@ main(int argc, char **argv)
 	u_int flags;
 # endif /* TEST_KEEP_FILES */
 	int nhdrs;
+	int nsigs;
 	DKIM_STAT status;
 	DKIM *dkim;
 	DKIM_LIB *lib;
+	DKIM_SIGINFO **sigs;
 	dkim_query_t qtype = DKIM_QUERY_FILE;
 	unsigned char hdr[MAXHEADER + 1];
 	char *ohdrs[MAXHDRCNT];
@@ -146,8 +148,14 @@ main(int argc, char **argv)
 	status = dkim_eom(dkim, NULL);
 	assert(status == DKIM_STAT_OK);
 
+	status = dkim_getsiglist(dkim, &sigs, &nsigs);
+	assert(status == DKIM_STAT_OK);
+	assert(sigs != NULL);
+	assert(sigs[0] != NULL);
+	assert(nsigs == 1);
+
 	nhdrs = MAXHDRCNT;
-	status = dkim_ohdrs(dkim, ohdrs, &nhdrs);
+	status = dkim_ohdrs(dkim, sigs[0], ohdrs, &nhdrs);
 	assert(status == DKIM_STAT_OK);
 	assert(nhdrs == 8);
 	assert(strcmp(ohdrs[0], HEADER02) == 0);
@@ -161,6 +169,8 @@ main(int argc, char **argv)
 
 	status = dkim_free(dkim);
 	assert(status == DKIM_STAT_OK);
+
+	dkim_close(lib);
 #endif /* ! DKIM_SIGN_RSASHA256 */
 
 	return 0;
