@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.8 2007/05/24 18:33:19 msk Exp $";
+static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.9 2007/09/17 16:37:22 msk Exp $";
 #endif /* !lint */
 
 #define	HEADER01	"Received: received data 0"
@@ -85,3 +85,5 @@ static char t_testdata_h[] = "@(#)$Id: t-testdata.h,v 1.8 2007/05/24 18:33:19 ms
 #define	SELECTOR	"test"
 #define	SELECTOR2	"brisbane"
 #define	DOMAIN		"example.com"
+#define	DOMAIN2		"sendmail.com"
+#define	REPLYADDRESS	"postmaster@localhost"
